@@ -32,7 +32,7 @@
 #include <KIconLoader>
 #include <KLocalizedString>
 #include "korganizerplugin_debug.h"
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 #include <QAction>
 #include <QIcon>
 
